@@ -3,7 +3,7 @@ package XML::Genx;
 use strict;
 use warnings;
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 # Use XSLoader first if possible.
 eval {
@@ -21,7 +21,7 @@ __END__
 
 =head1 NAME
 
-XML::Genx - Simple, correct XML writer
+XML::Genx - A simple, correct XML writer
 
 =head1 SYNOPSIS
 
@@ -42,12 +42,15 @@ XML::Genx - Simple, correct XML writer
 This class is used for generating XML.  The underlying library (genx)
 ensures that the output is well formed, canonical XML.  That is, all
 characters are correctly encoded, namespaces are handled properly and
-so on.
+so on.  If you manage to generate non-well-formed XML using XML::Genx,
+please submit a bug report.
 
 The API is mostly a wrapper over the original C library.  Consult the
 genx documentation for the fine detail.  This code is based on genx
 I<beta5>.
 
+For more detail on how to use this class, see L</EXAMPLES>.
+
 =head1 METHODS
 
 All methods will die() when they encounter an error.  Otherwise they
@@ -61,7 +64,9 @@ Constructor.  Returns a new L<XML::Genx> object.
 
 =item StartDocFile ( FILEHANDLE )
 
-Starts writing output to FILEHANDLE.
+Starts writing output to FILEHANDLE.  You have to open this yourself.
+
+This method will not accept a filename.
 
 =item StartDocSender ( CALLBACK )
 
@@ -86,13 +91,15 @@ Finishes writing to the output stream.
 
 =item StartElementLiteral ( [NAMESPACE], LOCALNAME )
 
-Starts an element LOCALNAME, in NAMESPACE.  If NAMESPACE is not
-present or undef, or an empty string, no namespace is used.
+Starts an element LOCALNAME, in NAMESPACE.  If NAMESPACE is not present
+or undef, or an empty string, no namespace is used.  NAMESPACE can
+either be a string or an XML::Genx::Namespace object.
 
 =item AddAttributeLiteral ( [NAMESPACE], LOCALNAME, VALUE )
 
 Adds an attribute LOCALNAME, with contents VALUE.  If NAMESPACE is not
-present or undef, or an empty string, no namespace is used.
+present or undef, or an empty string, no namespace is used.  NAMESPACE
+can either be a string or an XML::Genx::Namespace object.
 
 =item EndElement ( )
 
@@ -246,6 +253,119 @@ sits on top of Genx.
 
 =back
 
+=head1 EXAMPLES
+
+=over 4
+
+=item *
+
+Simple XML, with no namespaces or attributes.
+
+  $w->StartDocFile( *STDOUT );
+  $w->StartElementLiteral( 'strong' );
+  $w->AddText( 'bad' );
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <strong>bad</strong>
+
+=item *
+
+XML with attributes.
+
+  $w->StartDocFile( *STDOUT );
+  $w->StartElementLiteral( 'a' );
+  $w->AddAttributeLiteral( href => 'http://www.cpan.org/' );
+  $w->AddText( 'CPAN' );
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <a href="http://www.cpan.org/">CPAN</a>
+
+
+=item *
+
+XML with a default namespace.  Note that you have to explicitly pass in
+an empty string to specify the default namespace.  Just leaving out the
+second argument will result in an autogenerated prefix instead.
+
+  $w->StartDocFile( *STDOUT );
+  my $ns = $w->DeclareNamespace( "http://www.w3.org/1999/xhtml", "" );
+  $w->StartElementLiteral( $ns, 'strong' );
+  $w->AddText( 'bad' );
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <strong xmlns="http://www.w3.org/1999/xhtml">bad</strong>
+
+=item *
+
+XML with prefixed namespaces.
+
+  $w->StartDocFile( *STDOUT );
+  my $ns = $w->DeclareNamespace( "http://www.w3.org/1999/xhtml", "xh" );
+  $w->StartElementLiteral( $ns, 'strong' );
+  $w->AddText( 'bad' );
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <xh:strong xmlns:xh="http://www.w3.org/1999/xhtml">bad</xh:strong>
+
+=item *
+
+XML with attributes in a namespace.
+
+  $w->StartDocFile( *STDOUT );
+  my $ns = $w->DeclareNamespace( "http://www.w3.org/1999/xlink", "x" );
+  $w->StartElementLiteral( 'user' );
+  $w->AddAttributeLiteral( $ns, href => '/user/42' );
+  $w->AddText( 'Fred' );
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <user xmlns:x="http://www.w3.org/1999/xlink" x:href="/user/42">Fred</user>
+
+=item *
+
+Declaring elements.  If you are going to be using the same element many
+times over, it's worthwhile to predeclare it, since genx doesn't have to
+check the validity of the element name on each call.
+
+  $w->StartDocFile( *STDOUT );
+  my $ns = $w->DeclareNamespace( 'http://www.w3.org/1999/xhtml', "" );
+  my $li = $w->DeclareElement( 'li' );
+  $w->StartElementLiteral( 'ul' );
+
+  $li->StartElement();
+  $w->AddText( 'Fred' );
+  $w->EndElement();
+
+  $li->StartElement();
+  $w->AddText( 'Barney' );
+  $w->EndElement();
+
+  $w->EndElement();
+  $w->EndDocument();
+
+This produces:
+
+  <ul xmlns="http://www.w3.org/1999/xhtml"><li>Fred</li><li>Barney</li></ul>
+
+You might also want to look at L<XML::Genx::Simple/Element>, which does
+this for you (when there aren't any namespace involved).
+
+=back
+
 =head1 SEE ALSO
 
 L<XML::Genx::Constants>, L<XML::Genx::Simple>.
@@ -300,6 +420,6 @@ permission, see L<http://www.tbray.org/ongoing/genx/COPYING>.
 
 =head1 VERSION
 
-@(#) $Id: Genx.pm 885 2005-09-02 20:18:24Z dom $
+@(#) $Id: Genx.pm 992 2005-10-16 22:23:03Z dom $
 
 =cut
