@@ -8,7 +8,7 @@ use XML::Genx::Simple;
 
 use base 'XML::SAX::Base';
 
-our $VERSION = '0.18';
+our $VERSION = '0.19';
 
 sub new {
     my $class = shift;
@@ -64,7 +64,11 @@ sub start_element {
     $self->_new_element( $ns, $data->{ LocalName } )->StartElement;
 
     while ( my $ns = $self->_pop_ns ) {
-        $self->_new_namespace( @$ns )->AddNamespace;
+        # In order to get default namespaces done correctly, we have to
+        # specify the prefix explicitly to AddNamespace().  See comments
+        # above _declare_namespace().
+        my ( $uri, $prefix ) = @$ns;
+        $self->_new_namespace( $uri, $prefix )->AddNamespace( $prefix );
     }
 
     foreach ( values %{ $data->{ Attributes } || {} } ) {
@@ -155,7 +159,24 @@ sub _new_namespace {
     my ( $nsuri, $prefix ) = @_;
     return unless $nsuri;
     return $self->{ namespace }{ $nsuri } ||=
-        $self->_w->DeclareNamespace( $nsuri, $prefix );
+        $self->_declare_namespace( $nsuri, $prefix );
+}
+
+# Get Genx to give us a new namespace object.  NB: If a default
+# namespace is requested, we ask Genx to assign an autogenerated prefix
+# instead.  This gets countered further up in start_element().  When we
+# call AddNamespace(), we pass in the requested prefix instead, which
+# will be "" in case of the default namespace.  This is all in order to
+# work around Genx, which will not let you declare two namespaces with
+# the default prefix.
+sub _declare_namespace {
+    my $self = shift;
+    my ( $nsuri, $prefix ) = @_;
+    if ( $prefix ) {
+        return $self->_w->DeclareNamespace( $nsuri, $prefix );
+    } else {
+        return $self->_w->DeclareNamespace( $nsuri );
+    }
 }
 
 sub _new_element {
@@ -228,6 +249,6 @@ L<XML::SAX::Base> interface.
 
 =head1 VERSION
 
-@(#) $Id: SAXWriter.pm 885 2005-09-02 20:18:24Z dom $
+@(#) $Id: SAXWriter.pm 988 2005-10-16 21:46:18Z dom $
 
 =cut
